@@ -5,11 +5,12 @@ from django.core.exceptions import ValidationError
 from django.test import TestCase
 from django_mock_queries.query import MockModel, MockSet
 from edc_constants.constants import NO, NORMAL, OTHER, YES
+from edc_form_validators.tests.mixins import FormValidatorTestMixin
 from edc_utils import get_utcnow
 
 from effect_form_validators.effect_subject import ChestXrayFormValidator as Base
 
-from ..mixins import FormValidatorTestMixin, TestCaseMixin
+from ..mixins import TestCaseMixin
 
 
 class ChestXrayMockModel(MockModel):
