@@ -745,7 +745,7 @@ class TestParticipantHistoryFormValidator(TestCaseMixin, TestCase):
         cleaned_data.update(
             {
                 "previous_oi_name": "Prev OI",
-                "previous_oi_date": (
+                "previous_oi_dx_date": (
                     cleaned_data.get("report_datetime").date() - relativedelta(months=3)
                 ),
             }
@@ -773,27 +773,27 @@ class TestParticipantHistoryFormValidator(TestCaseMixin, TestCase):
             str(cm.exception.error_dict.get("previous_oi_name")),
         )
 
-    def test_previous_oi_date_required_if_previous_oi_yes(self):
+    def test_previous_oi_dx_date_required_if_previous_oi_yes(self):
         cleaned_data = self.get_cleaned_data()
         cleaned_data.update(
             {
                 "previous_oi": YES,
                 "previous_oi_name": "Prev OI",
-                "previous_oi_date": None,
+                "previous_oi_dx_date": None,
             }
         )
         form_validator = ParticipantHistoryFormValidator(cleaned_data=cleaned_data)
         with self.assertRaises(ValidationError) as cm:
             form_validator.validate()
-        self.assertIn("previous_oi_date", cm.exception.error_dict)
+        self.assertIn("previous_oi_dx_date", cm.exception.error_dict)
         self.assertIn(
             "This field is required.",
-            str(cm.exception.error_dict.get("previous_oi_date")),
+            str(cm.exception.error_dict.get("previous_oi_dx_date")),
         )
 
         cleaned_data.update(
             {
-                "previous_oi_date": (
+                "previous_oi_dx_date": (
                     cleaned_data.get("report_datetime").date() - relativedelta(months=3)
                 ),
             }
@@ -804,12 +804,12 @@ class TestParticipantHistoryFormValidator(TestCaseMixin, TestCase):
         except ValidationError as e:
             self.fail(f"ValidationError unexpectedly raised. Got {e}")
 
-    def test_previous_oi_date_not_required_if_previous_oi_no(self):
+    def test_previous_oi_dx_date_not_required_if_previous_oi_no(self):
         cleaned_data = self.get_cleaned_data()
         cleaned_data.update(
             {
                 "previous_oi": NO,
-                "previous_oi_date": (
+                "previous_oi_dx_date": (
                     cleaned_data.get("report_datetime").date() - relativedelta(months=3)
                 ),
             }
@@ -817,19 +817,19 @@ class TestParticipantHistoryFormValidator(TestCaseMixin, TestCase):
         form_validator = ParticipantHistoryFormValidator(cleaned_data=cleaned_data)
         with self.assertRaises(ValidationError) as cm:
             form_validator.validate()
-        self.assertIn("previous_oi_date", cm.exception.error_dict)
+        self.assertIn("previous_oi_dx_date", cm.exception.error_dict)
         self.assertIn(
             "This field is not required.",
-            str(cm.exception.error_dict.get("previous_oi_date")),
+            str(cm.exception.error_dict.get("previous_oi_dx_date")),
         )
 
-    def test_previous_oi_date_after_report_date_raises(self):
+    def test_previous_oi_dx_date_after_report_date_raises(self):
         cleaned_data = self.get_cleaned_data()
         cleaned_data.update(
             {
                 "previous_oi": YES,
                 "previous_oi_name": "Prev OI",
-                "previous_oi_date": (
+                "previous_oi_dx_date": (
                     cleaned_data.get("report_datetime").date() + relativedelta(days=1)
                 ),
             }
@@ -837,19 +837,19 @@ class TestParticipantHistoryFormValidator(TestCaseMixin, TestCase):
         form_validator = ParticipantHistoryFormValidator(cleaned_data=cleaned_data)
         with self.assertRaises(ValidationError) as cm:
             form_validator.validate()
-        self.assertIn("previous_oi_date", cm.exception.error_dict)
+        self.assertIn("previous_oi_dx_date", cm.exception.error_dict)
         self.assertIn(
             "Cannot be after report datetime",
-            str(cm.exception.error_dict.get("previous_oi_date")),
+            str(cm.exception.error_dict.get("previous_oi_dx_date")),
         )
 
-    def test_previous_oi_date_on_report_date_ok(self):
+    def test_previous_oi_dx_date_on_report_date_ok(self):
         cleaned_data = self.get_cleaned_data()
         cleaned_data.update(
             {
                 "previous_oi": YES,
                 "previous_oi_name": "Prev OI",
-                "previous_oi_date": cleaned_data.get("report_datetime").date(),
+                "previous_oi_dx_date": cleaned_data.get("report_datetime").date(),
             }
         )
         form_validator = ParticipantHistoryFormValidator(cleaned_data=cleaned_data)
@@ -858,13 +858,13 @@ class TestParticipantHistoryFormValidator(TestCaseMixin, TestCase):
         except ValidationError as e:
             self.fail(f"ValidationError unexpectedly raised. Got {e}")
 
-    def test_previous_oi_date_before_report_date_ok(self):
+    def test_previous_oi_dx_date_before_report_date_ok(self):
         cleaned_data = self.get_cleaned_data()
         cleaned_data.update(
             {
                 "previous_oi": YES,
                 "previous_oi_name": "Prev OI",
-                "previous_oi_date": (
+                "previous_oi_dx_date": (
                     cleaned_data.get("report_datetime").date() - relativedelta(days=1)
                 ),
             }
